From 4454f2a63394b69fba2c900151165ad8b5742f31 Mon Sep 17 00:00:00 2001
From: Mart Raudsepp <leio@gentoo.org>
Date: Sun, 15 Mar 2020 14:34:39 +0200
Subject: [PATCH] meson: Support elogind

---
 meson.build       | 12 +++++++++---
 meson_options.txt |  1 +
 2 files changed, 10 insertions(+), 3 deletions(-)

diff --git a/meson.build b/meson.build
index ef5132c6..7f68aaae 100644
--- a/meson.build
+++ b/meson.build
@@ -124,8 +124,10 @@ enable_systemd = get_option('systemd')
 enable_systemd_session = get_option('systemd_session') != 'disable'
 use_systemd_session = get_option('systemd_session') == 'default'
 enable_systemd_journal = get_option('systemd_journal')
+enable_elogind = get_option('elogind')
 enable_consolekit = get_option('consolekit')
-if enable_systemd or enable_consolekit
+assert(not (enable_systemd and enable_elogind), 'Can not support systemd and elogind at once')
+if enable_systemd or enable_elogind or enable_consolekit
   session_bin_deps += dependency('gio-unix-2.0', version: glib_req_version)
 
   # Check for systemd
@@ -152,6 +154,10 @@ if enable_systemd or enable_consolekit
     endif
 
     session_tracking = 'systemd'
+  elif enable_elogind
+    libelogind_dep = dependency('libelogind', version: '>= 239.4')
+    session_bin_deps += libelogind_dep
+    session_tracking = 'elogind'
   endif
 
   # Check for ConsoleKit
@@ -161,7 +167,7 @@ if enable_systemd or enable_consolekit
 
     session_bin_deps += dbus_glib_dep
 
-    if enable_systemd
+    if enable_systemd or enable_elogind
       session_tracking += ' (with fallback to ConsoleKit)'
     else
       session_tracking = 'ConsoleKit'
@@ -171,7 +177,7 @@ endif
 if enable_systemd_session
   assert(enable_systemd, 'Systemd support must be enabled when using systemd session management')
 endif
-config_h.set('HAVE_SYSTEMD', enable_systemd)
+config_h.set('HAVE_SYSTEMD', enable_systemd or enable_elogind)
 config_h.set('ENABLE_SYSTEMD_SESSION', enable_systemd_session)
 config_h.set('ENABLE_SYSTEMD_JOURNAL', enable_systemd_journal)
 config_h.set('HAVE_CONSOLEKIT', enable_consolekit)
diff --git a/meson_options.txt b/meson_options.txt
index 4c05dc6e..512d1528 100644
--- a/meson_options.txt
+++ b/meson_options.txt
@@ -1,4 +1,5 @@
 option('deprecation_flags', type: 'boolean', value: false, description: 'use *_DISABLE_DEPRECATED flags')
+option('elogind', type: 'boolean', value: true, description: 'Use elogind')
 option('session_selector', type: 'boolean', value: false, description: 'enable building a custom session selector dialog')
 option('systemd', type: 'boolean', value: true, description: 'Use systemd')
 option('systemd_session', type: 'combo', choices: ['disable', 'enable', 'default'], value: 'default', description: 'Whether to include systemd session support and use it by default')
-- 
2.26.2
